@@ -5,6 +5,9 @@
 # Model identifier for the model.list:
 THIS.MODEL <- "gas_pbtk"
 
+# Dose this model work with Monte Carlo parameter sampling?
+model.list[[THIS.MODEL]]$monte.carlo <- TRUE
+
 #Analytic expression for steady-state plasma concentration.
 #model.list[[THIS.MODEL]]$analytic.css.func <- "calc_analytic_css_gas" # added by MB 4/8/2020
 
@@ -53,6 +56,8 @@ model.list[[THIS.MODEL]]$tissuelist=list(
 # how other parameters were calculated:
 model.list[[THIS.MODEL]]$param.names <- c(
   "BW",
+  "Caco2.Pab",
+  "Caco2.Pab.dist",
   "Clint",
   "Clint.dist",
   "Clmetabolismc",
